Figma2Flutter class

Constructors

Figma2Flutter(BuildContext context)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
no setter

Methods

fontSize(double value) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double value) → EdgeInsetsGeometry
paddingOnly({double left = 0, double top = 0, double right = 0, double bottom = 0}) → EdgeInsetsGeometry
paddingSymmetric({double vertical = 0, double horizontal = 0}) → EdgeInsetsGeometry
px(double value, Axis axisDirection) → double
spacer(double value, Axis axisDirection) → Widget
style({Color? color, Color? backgroundColor, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, String? fontFamily, String? googleFont, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Locale? locale, Paint? foreground, Paint? background, List<Shadow>? shadows, List<FontFeature>? fontFeatures, TextDecoration? decoration, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, TextOverflow? overflow}) → TextStyle
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited