FigmaText class

Inheritance

Constructors

FigmaText(String text, {required double height, Key? key, TextStyle? style, double? width, AlignmentGeometry alignment = Alignment.centerLeft, TextAlign? textAlign, TextOverflow? overflow, int? maxLines, StrutStyle? strutStyle, TextDirection? textDirection, Locale? locale, bool? softWrap, TextScaler? textScaler, String? semanticsLabel, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, Color? selectionColor})
const

Properties

alignment → AlignmentGeometry
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
final
maxLines → int?
final
overflow → TextOverflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionColor → Color?
final
semanticsLabel → String?
final
softWrap → bool?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
text → String
final
textAlign → TextAlign?
final
textDirection → TextDirection?
final
textHeightBehavior → TextHeightBehavior?
final
textScaler → TextScaler?
final
textWidthBasis → TextWidthBasis?
final
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited